@@ -1,3 +1,4 @@
+from audioop import add
 import functools
 import inspect
 import time
@@ -7,6 +8,7 @@ from typing import Callable, Union, Dict
 import backoff
 from firebase_admin import auth as firebase_auth
 from flask import request
+from pydash import get
 from google.cloud.exceptions import ServiceUnavailable
 
 from arcane.core import CLIENTS_PARAM, ALL_CLIENTS_RIGHTS, RightsLevelEnum, GOOGLE_EXCEPTIONS_TO_RETRY, BadRequestError
@@ -34,9 +36,10 @@ def check_access_rights(service: str,
                         service_user_right: str,  # should be something like ValueOf[UserRightsEnum]
                         datastore_client: DatastoreClient,
                         pubsub_client: PubSubClient,
+                        kwargs_name_and_path_to_get: Dict[str, str] = {},
                         receive_rights_per_client: bool=False,
                         auth_enabled: bool=True,
-                        project: str=None
+                        project: str = None
                         ) -> Callable[[Callable], Callable]:
     """
     This functions checks the authorizations from the current HTTP call.
@@ -44,6 +47,7 @@ def check_access_rights(service: str,
     a function in order to get job_func_signature.
     if receive_rights_per_client is set to True, function must accept an argument corresponding to CLIENTS_PARAM either
     as the last positional argument or as an named argument.
+    :param kwargs_name_and_path_to_get: A dictionnary where the key is the name of the key we want to store the kwarg as and the value is the path to the value in the args ('test.value').
     """
     if required_rights == RightsLevelEnum.NONE and not receive_rights_per_client:
         def dummy_check_rights(job_func: Callable) -> Callable:
@@ -134,6 +138,12 @@ def check_access_rights(service: str,
             executable = job_func(*args, **kwargs)
             end = time.time()
 
+            additionnal_info = {}
+            for key, path in kwargs_name_and_path_to_get.items():
+                additionnal_info[key] = get(kwargs, path)
+            if len(additionnal_info.keys()) == 0:
+                additionnal_info = None
+
             if auth_enabled:
                 try:
                     send_tracking_information(
@@ -143,6 +153,7 @@ def check_access_rights(service: str,
                         origin=origin,
                         project=project,
                         execution_time=end - start,
+                        additionnal_info=additionnal_info,
                         pubsub_client=pubsub_client,
                         datastore_client=datastore_client)
                 except (KeyError, ServiceUnavailable):
