@@ -1,6 +1,8 @@
 from datetime import datetime
 import pytz
 import uuid
+import json
+from typing import Optional, Dict
 
 
 from .log import adscale_log
@@ -18,6 +20,7 @@ def send_tracking_information(
     origin: str,
     project: str,
     execution_time: float,
+    additionnal_info: Optional[Dict],
     pubsub_client: PubSubClient,
     datastore_client: DatastoreClient) -> None:
     """ Send pubsub message to the tracking cloud function"""
@@ -36,6 +39,7 @@ def send_tracking_information(
             parameters={'user_email': email,
              'service': service,
              'execution_time': execution_time,
+             'additionnal_info': json.dumps(additionnal_info) if additionnal_info is not None else None,
              'timestamp': timestamp,
              'function_name': function_name,
              'insert_id': insert_id,
